<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://rescuethemes.com
 * @since      1.0.0
 *
 * @package    Nutritionwp
 * @subpackage Nutritionwp/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Nutritionwp
 * @subpackage Nutritionwp/includes
 * @author     rescuethemes.com <plugins@rescuethemes.com>
 */
class Nutritionwp {
	
	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Nutritionwp_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->plugin_name = 'nutritionwp';
		$this->version = '1.1';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Nutritionwp_Loader. Orchestrates the hooks of the plugin.
	 * - Nutritionwp_i18n. Defines internationalization functionality.
	 * - Nutritionwp_Admin. Defines all hooks for the admin area.
	 * - Nutritionwp_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-nutritionwp-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-nutritionwp-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-nutritionwp-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-nutritionwp-public.php';
		
		/**
		 * Load admin settings display
		 * 
		 */
		require plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/nutritionwp-admin-display.php';
		
		/**
		 * Load CMB2
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/CMB2/init.php';
		 
		/**
		 * The class responsible for defining a post.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-nwp-post.php';
		 
		/**
		 * The class responsible for defining a Recipe.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/recipes/class-NWP_Recipe.php';
		
		/**
		 *  Directions Template Functions.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/recipes/directions-template-functions.php';
		
		/**
		 *  Ingredient Template Functions.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/recipes/ingredients-template-functions.php';
		
		/**
		 *  Ingredient Details Functions.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/recipes/details-template-functions.php';
		


		
		
		
		
		$this->loader = new Nutritionwp_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Nutritionwp_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Nutritionwp_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Nutritionwp_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'init', $plugin_admin, 'register_cpt' );
		$this->loader->add_action( 'init', $plugin_admin, 'add_images' );
		$this->loader->add_action( 'init', $plugin_admin, 'register_taxonomies' );
		$this->loader->add_action( 'cmb2_admin_init', $plugin_admin, 'register_custom_meta_boxes' );
		$this->loader->add_action( 'cmb2_admin_init', $plugin_admin, 'serving_type_cmb2_callback' );
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'add_menu_page' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'register_settings');
		$this->loader->add_filter( 'gettext', $plugin_admin, 'rename_excerpt_to_description', 10, 2 );
		$this->loader->add_filter('manage_nutritionwp-recipe_posts_columns', $plugin_admin, 'add_admin_column');
		$this->loader->add_action('manage_nutritionwp-recipe_posts_custom_column', $plugin_admin, 'add_admin_column_content', 10, 2);
		
		
		$this->loader->add_action( 'cmb2_render_link_picker_nwp', $plugin_admin, 'cmb2_render_link_picker_nwp', 10, 5 );
		$this->loader->add_filter( 'cmb2_sanitize_link_picker_nwp', $plugin_admin, 'cmb2_sanitize_link_picker_nwp_split', 12, 4 );
		$this->loader->add_filter( 'cmb2_sanitize_link_picker_nwp', $plugin_admin, 'cmb2_sanitize_link_picker_nwp', 10, 5 );
		$this->loader->add_filter( 'cmb2_types_esc_link_picker_nwp', $plugin_admin, 'cmb2_types_esc_link_picker_nwp', 10, 4 );
		
		$this->loader->add_action( 'cmb2_render_link_picker_text_nwp', $plugin_admin, 'cmb2_render_link_picker_text_nwp', 10, 5 );
		$this->loader->add_filter( 'cmb2_sanitize_link_picker_text_nwp', $plugin_admin, 'cmb2_sanitize_link_picker_nwp_split', 12, 4 );
		$this->loader->add_filter( 'cmb2_sanitize_link_picker_text_nwp', $plugin_admin, 'cmb2_sanitize_link_picker_nwp', 10, 5 );
		$this->loader->add_filter( 'cmb2_types_esc_link_picker_text_nwp', $plugin_admin, 'cmb2_types_esc_link_picker_nwp', 10, 4 );
		
		$this->loader->add_action( 'edit_form_after_editor', $plugin_admin, 'render_placeholder_wysiwyg', 0 );
		
		// Version 2
		//$this->loader->add_action( 'media_buttons', $plugin_admin, 'add_media_button' );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Nutritionwp_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		
		// Add the recipe to the bottom of single content.
		$this->loader->add_filter( 'the_content', $plugin_public, 'append_nwp_recipe_template' );
		
		// Add recipe schema to title
		$this->loader->add_filter( 'the_title', $plugin_public, 'nwp_add_title_schema', 10, 2 );

		// Add recipe schema to featured image
		$this->loader->add_filter( 'wp_get_attachment_image_attributes', $plugin_public, 'nwp_add_featured_image_schema', 10, 2 );
		
		// Add the recipe schema markup at beginning. This is so the image and title are within the recipe markup object.
		$this->loader->add_action( 'loop_start', $plugin_public, 'begin_recipe_schema_wrap' );

		// Add the recipe schema markup at end. This is so the image and title are within the recipe markup object
		$this->loader->add_action( 'loop_end', $plugin_public, 'end_recipe_schema_wrap' );
		
		// Register shortcodes
		$this->loader->add_action( 'init', $plugin_public, 'register_shortcodes' );




		

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Nutritionwp_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
