<?php

/**
 * Base class to represent a WordPress Post
 */
abstract class NWP_Post {

	protected $post;

	protected static $post_type = 'post';

	public function __construct( $post ) {

		if ( is_numeric( $post ) ) {
			$post = get_post( $post );
		}

		$this->post = $post;
	}

	/**
	 * Get the proper object based on its post ID
	 *
	 * @param int
	 */
	public static function get_by_post_id( $post_id ) {

		if ( ! $post_id ) {
			return false;
		}

		$post = get_post( $post_id );
		if ( ! $post ) {
			return false;
		}
		$class = ucwords( str_replace( 'nutritionwp-', 'NWP_', $post->post_type ), "_" );
		if ( ! class_exists( $class ) ) {
			return false;
		}

		return new $class( $post );
	}

	/**
	 * Get the ID for the post
	 *
	 * @return int
	 */
	public function get_id() {
		return $this->get_field( 'ID' );
	}

	/**
	 * Get the title for the post
	 *
	 * @return string
	 */
	public function get_title() {
		return $this->get_field( 'post_title' );
	}

	/**
	 * Print the title for the post
	 */
	public function the_title() {
		echo apply_filters( 'the_title', $this->get_title() );
	}

	/**
	 * Get the name of the post (used in the permalink)
	 *
	 * @param string
	 */
	public function get_name() {
		return $this->get_field( 'post_name' );
	}

	/**
	 * Get the type of post
	 *
	 * @return string
	 */
	public function get_type() {
		return static::$post_type;
	}

	/**
	 * Get the status of the post
	 *
	 * @return string
	 */
	public function get_status() {
		return $this->get_field( 'post_status' );
	}

	/**
	 * Get the excerpt for the post
	 *
	 * @return string
	 */
	public function get_excerpt() {
		return $this->get_field( 'post_excerpt' );
	}

	/**
	 * Print the excerpt for the post
	 */
	public function the_excerpt() {
		echo apply_filters( 'the_excerpt', $this->get_excerpt() );
	}

	/**
	 * Get the content for the post
	 *
	 * @return string
	 */
	public function get_content() {
		return $this->get_field( 'post_content' );
	}

	/**
	 * Print the content for the post
	 */
	public function the_content() {
		echo apply_filters( 'the_content', $this->get_content() );
	}

	/**
	 * Get the permalink for the post
	 *
	 * @return string
	 */
	public function get_permalink() {
		return get_permalink( $this->get_id() );
	}

	/**
	 * Print the permalink for the post
	 */
	public function the_permalink() {
		echo apply_filters( 'the_permalink', $this->get_permalink() );
	}

	/**
	 * Get the share link for the post
	 *
	 * @return string
	 */
	public function get_share_link() {
		return wp_get_shortlink( $this->get_id(), 'post' );
	}

	/**
	 * Get the post date for the post
	 *
	 * @param string $format
	 * @return string
	 */
	public function get_post_date( $format = 'U' ) {
		return date( $format, strtotime( $this->get_field( 'post_date' ) ) );
	}

	/**
	 * Get the post date gmt for the post
	 *
	 * @return string
	 */
	public function get_post_date_gmt() {
		return $this->get_field( 'post_date_gmt' );
	}

	/**
	 * Get the post modified date for the post
	 *
	 * @return string
	 */
	public function get_post_modified() {
		return $this->get_field( 'post_modified' );
	}

	/**
	 * Get the post modified date for the post
	 *
	 * @return string
	 */
	public function get_post_modified_gmt() {
		return $this->get_field( 'post_modified_gmt' );
	}

	/**
	 * Get the parent id for the post
	 *
	 * @return string
	 */
	public function get_parent_id() {
		return (int) $this->get_field( 'post_parent' );
	}

	/**
	 * Get CSS classes
	 */
	public function get_css_classes() {
		return 'content-object';
	}

	/**
	 * Whether or not this post has a featured image
	 *
	 * @return bool
	 */
	public function has_featured_image() {
		return (bool) $this->get_featured_image();;
	}

	/**
	 * Get the featured image ID for the post
	 *
	 * @return int|false
	 */
	public function get_featured_image_id() {
		return (int) $this->get_meta( '_thumbnail_id' );
	}

	/**
	 * Get a field from the post object
	 *
	 * @param string $key
	 * @return mixed
	 */
	protected function get_field( $key ) {
		return $this->post->$key;
	}

	/**
	 * Get a Fieldmanager field
	 *
	 * @param string
	 * @return mixed
	 */
	protected function get_fm_field() {

		$fields = func_get_args();
		$parent = array_shift( $fields );

		$meta = $this->get_meta( $parent );
		foreach( $fields as $key ) {
			if ( isset( $meta[ $key ] ) ) {
				$meta = $meta[ $key ];
			} else {
				return false;
			}
		}
		return $meta;

	}

	/**
	 * Get a meta value for a post
	 *
	 * @param string
	 * @return mixed
	 */
	protected function get_meta( $key ) {
		return get_post_meta( $this->get_id(), $key, true );
	}

	/**
	 * Get the taxonomy terms for a post
	 *
	 * @param string $taxonomy
	 * @return array|false
	 */
	protected function get_taxonomy_terms( $taxonomy ) {

		$terms = get_the_terms( $this->get_id(), $taxonomy );
		if ( $terms && ! is_wp_error( $terms ) ) {
			return $terms;
		} else {
			return false;
		}

	}


}