<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://rescuethemes.com
 * @since      1.0.0
 *
 * @package    Nutritionwp
 * @subpackage Nutritionwp/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Nutritionwp
 * @subpackage Nutritionwp/public
 * @author     rescuethemes.com <plugins@rescuethemes.com>
 */
class Nutritionwp_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param    string    $plugin_name The name of the plugin.
	 * @param    string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since	1.0.0
	 */
	public function enqueue_styles() {

		 // Check if front end styles should be enabled
		if ( ! get_option('nwp_settings')['enable_css'] ) {

			wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/nutritionwp-public.css', array(), $this->version, 'all' );
		
		}

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Nutritionwp_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Nutritionwp_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		 
		//wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/nutritionwp-public.js', array( 'jquery' ), $this->version, false );

	}
	
	/**
	 * Registers shortcodes
	 *
	 * @since    1.0.0
	 * @access private
	 * @return void
	 */
	public function register_shortcodes() {

		add_shortcode( 'nwp_recipe', array( $this, 'nwp_display_recipe_shortcode' ) );

	} 
	
	/**
	 * Check if post is nwp cpt
	 * 
	 * @since    1.0.0
	 * @access private
	 * @return void
	 */
	private function can_append_recipe() { 
		global $post;
		
		if ( $post->post_type == "nutritionwp-recipe" ) {
		
			return true;
			
		} else {
			
			return false;
			
		}
	
	}

	
	/**
	 * Append recipe to post content
	 * 
	 * @access public
	 * @param mixed $content
	 * @return void
	 */
	public function append_nwp_recipe_template( $content ) {
		
		if ( ! $this->can_append_recipe() ) {
			return $content;
		}

		ob_start();

		$this->nwp_get_template( 'content-nutritionwp-recipe.php' );
		
		return ob_get_clean();
		
	}
	
	
	/**
	 * Add recipe schema to title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @param mixed $title
	 * @param int $id (default: 0)
	 * @return $schema_title String
	 */
	public function nwp_add_title_schema( $title, $id = 0 ) {

		$schema_title = $title;

		if ( $id == get_the_ID() && is_singular( 'nutritionwp-recipe' ) && is_main_query() ) {

			$schema_title = '<span itemprop="name">';
			$schema_title .= $title;
			$schema_title .= '</span>';
		}

		return $schema_title;
	}

	
	/**
	 * Add recipe schema to featured image.
	 * 
	 * @since 	1.0.0
	 * @access	public
	 * @param	mixed $attributes
	 * @param	mixed $image
	 * @return	$attributes array
	 */
	public function nwp_add_featured_image_schema( $attributes, $image ) {

		if ( $image->ID == get_post_thumbnail_id( get_the_ID() ) && is_singular( 'nutritionwp-recipe' ) && is_main_query() ) {

			$attributes['itemprop'] = 'image';
		}

		return $attributes;
	}


	/**
	 * Wrap beginning of content in recipe schema
	 *
	 * @since	1.0.0
	 * @access	public
	 * @param	$query
	 * @return	void
	 */
	public function begin_recipe_schema_wrap( $query, $shortcode = false ) {
		
		if ( $shortcode ) {
			
			echo '<span class="nwp-shortcode" itemscope itemtype="http://schema.org/Recipe">';
			return;
			
		}
		
		if ( $query->is_singular( 'nutritionwp-recipe' ) && $query->is_main_query() ) {

			echo '<span itemscope itemtype="http://schema.org/Recipe">';
			
			$this->theme_compatibility();
			
		}
		
	}
	
	
	/**
	 * Wrap end of content in recipe schema
	 *
	 * @since	1.0.0
	 * @access	public
	 * @param	$query
	 * @return	void
	 */
	public function end_recipe_schema_wrap( $query, $shortcode = false ) {
		
		if ( $shortcode ) {
			
			echo '</span>';
			return;
			
		}
		
		if ( $query->is_singular( 'nutritionwp-recipe' ) && $query->is_main_query() ) {

			echo '</span>';
		}
	}
	
	
	
	/**
	 * If themes display the featured image before starting the loop. This will echo out the recipe image markup inside the recipe object.
	 *
	 * @since	1.0.0
	 * @access	public
	 * @return	void
	 */
	private function theme_compatibility() {
		
		global $post;
		
		// 2017 theme
		if ( function_exists( 'twentyseventeen_setup' ) ) {

			if ( has_post_thumbnail( $post->ID ) ) { 

				$image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'nwp-recipe-medium' );
	
				echo '<img itemprop="image" class="photo" src="' . $image[0] . '" style="display:none">';
	
			} 
		
		}
	}
	
	/**
	 * Locate the template.
	 * @since 1.0.0
	 *
	 * @param 	string 	$template_name			Template to load.
	 * @param 	string 	$string $template_path	Path to templates.
	 * @param 	string	$default_path			Default path to template files.
	 * @access	private
	 * @return 	string 							Path to the template file.
	 */
	private function nwp_locate_template( $template_name, $template_path = '', $default_path = '' ) {
	
		// Set variable to search in nutritionWP folder of theme.
		if ( ! $template_path ) :
			$template_path = 'nutritionwp-templates/';
		endif;
	
		// Set default plugin templates path.
		if ( ! $default_path ) :
			$default_path = plugin_dir_path( __DIR__ ) . 'public/templates/'; // Path to the template folder
		endif;
	
		// Search template file in theme folder.
		$template = locate_template( array(
			$template_path . $template_name,
			$template_name
		) );
		
		// Get plugins template file.
		if ( ! $template ) :
			$template = $default_path . $template_name;
		endif;
	
		return apply_filters( 'nwp_locate_template', $template, $template_name, $template_path, $default_path );
		
	}
	
	/**
	 * Search for the template and include the file.
	 *
	 * @since 1.0.0
	 *
	 * @param 	string 	$template_name			Template to load.
	 * @param 	array 	$args					Args passed for the template file.
	 * @param	string 	$string $template_path	Path to templates.
	 * @param 	string	$default_path			Default path to template files.
	 * @access	private
	 */
	private function nwp_get_template( $template_name, $args = array(), $tempate_path = '', $default_path = '' ) {
		
		if ( is_array( $args ) && isset( $args ) ) :
			extract( $args );
		endif;
	
		$template_file = $this->nwp_locate_template( $template_name, $tempate_path, $default_path );
		
		if ( ! file_exists( $template_file ) ) :
			_doing_it_wrong( __FUNCTION__, sprintf( '<code>%s</code> does not exist.', $template_file ), '1.0.0' );
			return;
		endif;
	
		include $template_file;
	
	}

	
	/**
	 * Processes shortcode
	 *
	 * @param   array	$atts		The attributes from the shortcode
	 *
	 * @uses	get_option
	 * @uses	get_layout
	 *
	 * @return	mixed	$output		Output of the buffer
	 */
	public function nwp_display_recipe_shortcode( $atts, $content = null ) {
	
		global $post, $query;
		
		$defaults = array(
				'id' => 0,
		);
		
		$atts = shortcode_atts( $defaults, $atts );

		// Get Recipe post
		$post = get_post( $atts['id'] );

		// Return if post id is invalid
		if ( !$post || $post->post_type != 'nutritionwp-recipe' ) {
			return;
		}

		ob_start();
		
		setup_postdata( $post );
		
		// Begin schema wrap
		$this->begin_recipe_schema_wrap( null, true );	
		
		$this->nwp_get_template( 'content-nutritionwp-recipe.php' );
		
		// Begin schema wrap
		$this->end_recipe_schema_wrap( null, true );
		
		// Reset the $post.
		wp_reset_postdata();
	
		return ob_get_clean();
	

	}

}
